### Introduction

SCSit: A high-efficiency cell types identification tool for single-cell sequencing data from SPLiT-seq

### Parameter description
All file_path are *Absolute path*, cause thread work direction may different with
file path. So path from content root is not suitable here.

#### Eg: 
```angular2html
    r1 = b"D:/Code/SCSit_Package/r1.fastq"
```
- param r1: Path of file1.fastq
- param r2: Path of file2.fastq

